;;; ispell-emacs-menu.el --- Produce the (x)emacs (i)spell menu on the fly

;; Copyright (c) 1999 SuSE Gmbh Nuernberg, Germany.  All rights reserved.
;; Copyright (c) 2017 SUSE Linux Gmbh Nürnberg, Germany.  All rights reserved.
;; Author: Werner Fink, <werner@suse.de> 1999/03/04,2017/02/28

;;; Note:

;; Do *not* byte-compile this file because its loaded by both emacs and xemacs

;;; The code:

(defvar ispell-library-path "/usr/lib/ispell/"
  "The library path used by the installed ispell package")

(defun  append-ispell-dict-alist (hash alist)
  "Simply append the specified list to ispell-dictionary-alist."
    (if (file-exists-p (concat ispell-library-path hash))
	(setq ispell-ispell-dictionary-alist
	   (append ispell-ispell-dictionary-alist (list alist)))))

(if (string-match "XEmacs\\|Lucid" emacs-version)
      (progn
	(if (not (coding-system-alias-p 'iso-latin-1))
	  (define-coding-system-alias 'iso-latin-1 'iso-8859-1))
	(if (not (coding-system-alias-p 'iso-latin-2))
	  (define-coding-system-alias 'iso-latin-2 'iso-8859-2))
	(if (not (coding-system-alias-p 'iso-latin-3))
	  (define-coding-system-alias 'iso-latin-3 'iso-8859-3))
	(if (not (coding-system-alias-p 'iso-latin-4))
	  (define-coding-system-alias 'iso-latin-4 'iso-8859-4))
	(if (not (coding-system-alias-p 'iso-latin-5))
	  (define-coding-system-alias 'iso-latin-5 'iso-8859-9))
	(if (not (coding-system-alias-p 'iso-latin-8))
	  (progn
	    (require 'latin-euro-latin8)
	    (define-coding-system-alias 'iso-latin-8 'iso-8859-14)))
	(if (not (coding-system-alias-p 'iso-latin-9))
	  (define-coding-system-alias 'iso-latin-9 'iso-8859-15))
	(if (not (memq (car ispell-menu-xemacs) '(:filter)))
	  (setq ispell-menu-xemacs nil)))
    (setq ispell-menu-map nil))

(setq ispell-ispell-dictionary-alist '(
	(nil "[[:alpha:]]" "[^[:alpha:]]" "[']" nil ("-B") nil nil)))

(when (and (listp 'ispell-local-dictionary-alist)
	   (not (null ispell-local-dictionary-alist)))
	(setq ispell-ispell-dictionary-alist
	      '((append ispell-local-dictionary-alist ispell-ispell-dictionary-alist))))

(let ((dir (directory-files (concat ispell-library-path "emacs/") t ".*\\.el$")))
     (while dir (load (car dir) nil t t) (setq dir (cdr dir))))

(setq ispell-dictionary-alist ispell-ispell-dictionary-alist)
(add-hook 'ispell-initialize-spellchecker-hook
      (lambda ()
    (setq ispell-base-dicts-override-alist ispell-ispell-dictionary-alist)))
;;
;; Now load the library to recreate the Spell menu in the Edit pulldown
;;
(load "ispell" nil t)

;;; ispell-emacs-menu.el end here
